@@ -15,9 +15,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import os
 import datetime
+import os
 from typing import Optional
+
 import pytest
 
 from ibm_cloud_sdk_core import string_to_datetime, datetime_to_string, get_authenticator_from_environment
@@ -117,6 +118,7 @@ def test_datetime_to_string():
     res = datetime_to_string(date)
     assert res == '2017-03-06T16:00:04.159338Z'
 
+
 def test_string_to_datetime_list():
     # Assert ValueError is raised for invalid argument type
     with pytest.raises(ValueError):
@@ -175,6 +177,7 @@ def test_datetime_to_string_list():
     res = datetime_to_string_list(date_list)
     assert res == [ '2017-03-06T16:00:04.159338Z', '2017-03-06T16:00:04.159338Z' ]
 
+
 def test_date_conversion():
     date = string_to_date('2017-03-06')
     assert date.day == 6
@@ -182,6 +185,7 @@ def test_date_conversion():
     assert res == '2017-03-06'
     assert date_to_string(None) is None
 
+
 def test_get_query_param():
     # Relative URL
     next_url = '/api/v1/offerings?start=foo&limit=10'
@@ -223,6 +227,7 @@ def test_get_query_param():
         # This is okay.
         pass
 
+
 def test_convert_model():
     class MockModel:
         def __init__(self, xyz: Optional[str] = None) -> None:
@@ -269,6 +274,7 @@ def test_convert_list():
     assert mock4_str == mock4
 
 
+# pylint: disable=too-many-statements
 def test_get_authenticator_from_credential_file():
     file_path = os.path.join(os.path.dirname(__file__),
                              '../resources/ibm-credentials-iam.env')
@@ -276,6 +282,11 @@ def test_get_authenticator_from_credential_file():
     authenticator = get_authenticator_from_environment('ibm watson')
     assert authenticator is not None
     assert authenticator.token_manager.apikey == '5678efgh'
+    assert authenticator.token_manager.url == 'https://iam.cloud.ibm.com'
+    assert authenticator.token_manager.client_id is None
+    assert authenticator.token_manager.client_secret is None
+    assert authenticator.token_manager.disable_ssl_verification is False
+    assert authenticator.token_manager.scope is None
     del os.environ['IBM_CREDENTIALS_FILE']
 
     file_path = os.path.join(os.path.dirname(__file__),
@@ -286,6 +297,32 @@ def test_get_authenticator_from_credential_file():
     assert authenticator.username == 'my_username'
     del os.environ['IBM_CREDENTIALS_FILE']
 
+    file_path = os.path.join(os.path.dirname(__file__),
+                             '../resources/ibm-credentials-container.env')
+    os.environ['IBM_CREDENTIALS_FILE'] = file_path
+    authenticator = get_authenticator_from_environment('service 1')
+    assert authenticator is not None
+    assert authenticator.token_manager.cr_token_filename == 'crtoken.txt'
+    assert authenticator.token_manager.iam_profile_name == 'iam-user-123'
+    assert authenticator.token_manager.iam_profile_id == 'iam-id-123'
+    assert authenticator.token_manager.url == 'https://iamhost/iam/api'
+    assert authenticator.token_manager.scope == 'scope1'
+    assert authenticator.token_manager.client_id == 'iam-client-123'
+    assert authenticator.token_manager.client_secret == 'iam-secret-123'
+    assert authenticator.token_manager.disable_ssl_verification is True
+
+    authenticator = get_authenticator_from_environment('service 2')
+    assert authenticator is not None
+    assert authenticator.token_manager.cr_token_filename is None
+    assert authenticator.token_manager.iam_profile_name == 'iam-user-123'
+    assert authenticator.token_manager.iam_profile_id is None
+    assert authenticator.token_manager.url == 'https://iam.cloud.ibm.com'
+    assert authenticator.token_manager.scope is None
+    assert authenticator.token_manager.client_id is None
+    assert authenticator.token_manager.client_secret is None
+    assert authenticator.token_manager.disable_ssl_verification is False
+    del os.environ['IBM_CREDENTIALS_FILE']
+
     file_path = os.path.join(os.path.dirname(__file__),
                              '../resources/ibm-credentials-cp4d.env')
     os.environ['IBM_CREDENTIALS_FILE'] = file_path
@@ -293,6 +330,9 @@ def test_get_authenticator_from_credential_file():
     assert authenticator is not None
     assert authenticator.token_manager.username == 'my_username'
     assert authenticator.token_manager.password == 'my_password'
+    assert authenticator.token_manager.url == 'https://my_url/v1/authorize'
+    assert authenticator.token_manager.apikey is None
+    assert authenticator.token_manager.disable_ssl_verification is False
     del os.environ['IBM_CREDENTIALS_FILE']
 
     file_path = os.path.join(os.path.dirname(__file__),
